==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/TriggerPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.TriggerPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The properties of a trigger.
 * @property baseImageTrigger The trigger based on base image dependencies.
 * @property sourceTriggers The collection of triggers based on source code repository.
 * @property timerTriggers The collection of timer triggers.
 */
public data class TriggerPropertiesArgs(
    public val baseImageTrigger: Output<BaseImageTriggerArgs>? = null,
    public val sourceTriggers: Output<List<SourceTriggerArgs>>? = null,
    public val timerTriggers: Output<List<TimerTriggerArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.TriggerPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.TriggerPropertiesArgs =
        com.pulumi.azurenative.containerregistry.inputs.TriggerPropertiesArgs.builder()
            .baseImageTrigger(baseImageTrigger?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .sourceTriggers(
                sourceTriggers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .timerTriggers(
                timerTriggers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [TriggerPropertiesArgs].
 */
@PulumiTagMarker
public class TriggerPropertiesArgsBuilder internal constructor() {
    private var baseImageTrigger: Output<BaseImageTriggerArgs>? = null

    private var sourceTriggers: Output<List<SourceTriggerArgs>>? = null

    private var timerTriggers: Output<List<TimerTriggerArgs>>? = null

    /**
     * @param value The trigger based on base image dependencies.
     */
    @JvmName("flntwecknvgttngw")
    public suspend fun baseImageTrigger(`value`: Output<BaseImageTriggerArgs>) {
        this.baseImageTrigger = value
    }

    /**
     * @param value The collection of triggers based on source code repository.
     */
    @JvmName("iwaxkbmrpntdisfb")
    public suspend fun sourceTriggers(`value`: Output<List<SourceTriggerArgs>>) {
        this.sourceTriggers = value
    }

    @JvmName("kmlfigklfbhhbexg")
    public suspend fun sourceTriggers(vararg values: Output<SourceTriggerArgs>) {
        this.sourceTriggers = Output.all(values.asList())
    }

    /**
     * @param values The collection of triggers based on source code repository.
     */
    @JvmName("lmlqufqmgvtbvagk")
    public suspend fun sourceTriggers(values: List<Output<SourceTriggerArgs>>) {
        this.sourceTriggers = Output.all(values)
    }

    /**
     * @param value The collection of timer triggers.
     */
    @JvmName("recpdahvtdqtsljx")
    public suspend fun timerTriggers(`value`: Output<List<TimerTriggerArgs>>) {
        this.timerTriggers = value
    }

    @JvmName("ycqbkusfiqyeemlb")
    public suspend fun timerTriggers(vararg values: Output<TimerTriggerArgs>) {
        this.timerTriggers = Output.all(values.asList())
    }

    /**
     * @param values The collection of timer triggers.
     */
    @JvmName("cyyithlqebynyiul")
    public suspend fun timerTriggers(values: List<Output<TimerTriggerArgs>>) {
        this.timerTriggers = Output.all(values)
    }

    /**
     * @param value The trigger based on base image dependencies.
     */
    @JvmName("ggdihoovskvlsipj")
    public suspend fun baseImageTrigger(`value`: BaseImageTriggerArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baseImageTrigger = mapped
    }

    /**
     * @param argument The trigger based on base image dependencies.
     */
    @JvmName("shgiwkfjvelifrjv")
    public suspend fun baseImageTrigger(argument: suspend BaseImageTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = BaseImageTriggerArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.baseImageTrigger = mapped
    }

    /**
     * @param value The collection of triggers based on source code repository.
     */
    @JvmName("hbjwohyakvjuiscq")
    public suspend fun sourceTriggers(`value`: List<SourceTriggerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceTriggers = mapped
    }

    /**
     * @param argument The collection of triggers based on source code repository.
     */
    @JvmName("citowymjrecirrwc")
    public suspend fun sourceTriggers(argument: List<suspend SourceTriggerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SourceTriggerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.sourceTriggers = mapped
    }

    /**
     * @param argument The collection of triggers based on source code repository.
     */
    @JvmName("wnbvigomglhkibmq")
    public suspend fun sourceTriggers(vararg argument: suspend SourceTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            SourceTriggerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.sourceTriggers = mapped
    }

    /**
     * @param argument The collection of triggers based on source code repository.
     */
    @JvmName("jaehmxsenaxmftub")
    public suspend fun sourceTriggers(argument: suspend SourceTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SourceTriggerArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.sourceTriggers = mapped
    }

    /**
     * @param values The collection of triggers based on source code repository.
     */
    @JvmName("hdkwcxyawwuvlnqm")
    public suspend fun sourceTriggers(vararg values: SourceTriggerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceTriggers = mapped
    }

    /**
     * @param value The collection of timer triggers.
     */
    @JvmName("mmudvfvfxiydpmkx")
    public suspend fun timerTriggers(`value`: List<TimerTriggerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timerTriggers = mapped
    }

    /**
     * @param argument The collection of timer triggers.
     */
    @JvmName("kpueqdxaiqcjrxbb")
    public suspend fun timerTriggers(argument: List<suspend TimerTriggerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TimerTriggerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.timerTriggers = mapped
    }

    /**
     * @param argument The collection of timer triggers.
     */
    @JvmName("kduhnxbfvlcgykhi")
    public suspend fun timerTriggers(vararg argument: suspend TimerTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            TimerTriggerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.timerTriggers = mapped
    }

    /**
     * @param argument The collection of timer triggers.
     */
    @JvmName("avvnfxhayxnfculf")
    public suspend fun timerTriggers(argument: suspend TimerTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TimerTriggerArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.timerTriggers = mapped
    }

    /**
     * @param values The collection of timer triggers.
     */
    @JvmName("mpuskoeayeywxvwk")
    public suspend fun timerTriggers(vararg values: TimerTriggerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.timerTriggers = mapped
    }

    internal fun build(): TriggerPropertiesArgs = TriggerPropertiesArgs(
        baseImageTrigger = baseImageTrigger,
        sourceTriggers = sourceTriggers,
        timerTriggers = timerTriggers,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/TriggerPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.TriggerPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The properties of a trigger.
 * @property baseImageTrigger The trigger based on base image dependencies.
 * @property sourceTriggers The collection of triggers based on source code repository.
 * @property timerTriggers The collection of timer triggers.
 */
public data class TriggerPropertiesArgs(
    public val baseImageTrigger: Output<BaseImageTriggerArgs>? = null,
    public val sourceTriggers: Output<List<SourceTriggerArgs>>? = null,
    public val timerTriggers: Output<List<TimerTriggerArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.TriggerPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.TriggerPropertiesArgs =
        com.pulumi.azurenative.containerregistry.inputs.TriggerPropertiesArgs.builder()
            .baseImageTrigger(baseImageTrigger?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .sourceTriggers(
                sourceTriggers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .timerTriggers(
                timerTriggers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [TriggerPropertiesArgs].
 */
@PulumiTagMarker
public class TriggerPropertiesArgsBuilder internal constructor() {
    private var baseImageTrigger: Output<BaseImageTriggerArgs>? = null

    private var sourceTriggers: Output<List<SourceTriggerArgs>>? = null

    private var timerTriggers: Output<List<TimerTriggerArgs>>? = null

    /**
     * @param value The trigger based on base image dependencies.
     */
    @JvmName("yogjwlgmcmmvxhpp")
    public suspend fun baseImageTrigger(`value`: Output<BaseImageTriggerArgs>) {
        this.baseImageTrigger = value
    }

    /**
     * @param value The collection of triggers based on source code repository.
     */
    @JvmName("rwcmvlxesenirmue")
    public suspend fun sourceTriggers(`value`: Output<List<SourceTriggerArgs>>) {
        this.sourceTriggers = value
    }

    @JvmName("dptykwugmgcgemvn")
    public suspend fun sourceTriggers(vararg values: Output<SourceTriggerArgs>) {
        this.sourceTriggers = Output.all(values.asList())
    }

    /**
     * @param values The collection of triggers based on source code repository.
     */
    @JvmName("gjyibpggsfpadjcn")
    public suspend fun sourceTriggers(values: List<Output<SourceTriggerArgs>>) {
        this.sourceTriggers = Output.all(values)
    }

    /**
     * @param value The collection of timer triggers.
     */
    @JvmName("amsfeurmqrggjfrw")
    public suspend fun timerTriggers(`value`: Output<List<TimerTriggerArgs>>) {
        this.timerTriggers = value
    }

    @JvmName("gxrrtfdfnabqblkm")
    public suspend fun timerTriggers(vararg values: Output<TimerTriggerArgs>) {
        this.timerTriggers = Output.all(values.asList())
    }

    /**
     * @param values The collection of timer triggers.
     */
    @JvmName("ftktwphaoqmlmqwv")
    public suspend fun timerTriggers(values: List<Output<TimerTriggerArgs>>) {
        this.timerTriggers = Output.all(values)
    }

    /**
     * @param value The trigger based on base image dependencies.
     */
    @JvmName("kqevpywocgalsafu")
    public suspend fun baseImageTrigger(`value`: BaseImageTriggerArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baseImageTrigger = mapped
    }

    /**
     * @param argument The trigger based on base image dependencies.
     */
    @JvmName("tyeibkofcajnourh")
    public suspend fun baseImageTrigger(argument: suspend BaseImageTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = BaseImageTriggerArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.baseImageTrigger = mapped
    }

    /**
     * @param value The collection of triggers based on source code repository.
     */
    @JvmName("wrjorcagvrwdxgfw")
    public suspend fun sourceTriggers(`value`: List<SourceTriggerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceTriggers = mapped
    }

    /**
     * @param argument The collection of triggers based on source code repository.
     */
    @JvmName("pbvpbedukihyxxhp")
    public suspend fun sourceTriggers(argument: List<suspend SourceTriggerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SourceTriggerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.sourceTriggers = mapped
    }

    /**
     * @param argument The collection of triggers based on source code repository.
     */
    @JvmName("syxvmgbsaeoyvkrj")
    public suspend fun sourceTriggers(vararg argument: suspend SourceTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            SourceTriggerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.sourceTriggers = mapped
    }

    /**
     * @param argument The collection of triggers based on source code repository.
     */
    @JvmName("mnllsejexlnhgyhn")
    public suspend fun sourceTriggers(argument: suspend SourceTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SourceTriggerArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.sourceTriggers = mapped
    }

    /**
     * @param values The collection of triggers based on source code repository.
     */
    @JvmName("rgemqyvnqqcmqvtp")
    public suspend fun sourceTriggers(vararg values: SourceTriggerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceTriggers = mapped
    }

    /**
     * @param value The collection of timer triggers.
     */
    @JvmName("kcmllxkoxscqapkr")
    public suspend fun timerTriggers(`value`: List<TimerTriggerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timerTriggers = mapped
    }

    /**
     * @param argument The collection of timer triggers.
     */
    @JvmName("peomqojwjtiegjyp")
    public suspend fun timerTriggers(argument: List<suspend TimerTriggerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TimerTriggerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.timerTriggers = mapped
    }

    /**
     * @param argument The collection of timer triggers.
     */
    @JvmName("tvkexctbveilkpup")
    public suspend fun timerTriggers(vararg argument: suspend TimerTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            TimerTriggerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.timerTriggers = mapped
    }

    /**
     * @param argument The collection of timer triggers.
     */
    @JvmName("bamsddialbwagphi")
    public suspend fun timerTriggers(argument: suspend TimerTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TimerTriggerArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.timerTriggers = mapped
    }

    /**
     * @param values The collection of timer triggers.
     */
    @JvmName("qfpsxxehjfoqeeik")
    public suspend fun timerTriggers(vararg values: TimerTriggerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.timerTriggers = mapped
    }

    internal fun build(): TriggerPropertiesArgs = TriggerPropertiesArgs(
        baseImageTrigger = baseImageTrigger,
        sourceTriggers = sourceTriggers,
        timerTriggers = timerTriggers,
    )
}
